@@ -16,8 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBMANETTE_H
-#define LIBMANETTE_H
+#pragma once
 
 #include <glib.h>
 
@@ -25,6 +24,7 @@ G_BEGIN_DECLS
 
 #define __MANETTE_INSIDE__
 # include "manette-device.h"
+# include "manette-device-type.h"
 # include "manette-event.h"
 # include "manette-monitor.h"
 # include "manette-monitor-iter.h"
@@ -32,5 +32,3 @@ G_BEGIN_DECLS
 #undef __MANETTE_INSIDE__
 
 G_END_DECLS
-
-#endif /* LIBMANETTE_H */
