@@ -23,12 +23,13 @@
 #endif
 
 #include "manette-device.h"
+#include "manette-backend-private.h"
 #include "manette-mapping-private.h"
 
 G_BEGIN_DECLS
 
-ManetteDevice *manette_device_new (const gchar  *filename,
-                                   GError      **error);
+ManetteDevice *manette_device_new (ManetteBackend  *backend,
+                                   GError         **error);
 int manette_device_get_product_id (ManetteDevice *self);
 int manette_device_get_vendor_id (ManetteDevice *self);
 int manette_device_get_bustype_id (ManetteDevice *self);
